==> fabric-cf-0.11.tar.gz: fabric-cf-0.11/fabric_cf/actor/core/policy/queue_wrapper.py <==
#!/usr/bin/env python3
# MIT License
#
# Copyright (c) 2020 FABRIC Testbed
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
#
# Author: Komal Thareja (kthare10@renci.org)
from __future__ import annotations

from abc import abstractmethod
from typing import TYPE_CHECKING, List

if TYPE_CHECKING:
    from fabric_cf.actor.core.apis.i_broker_reservation import IBrokerReservation


class QueueWrapper:
    @abstractmethod
    def add(self, *, reservation: IBrokerReservation):
        """
        Add a reservation
        @param reservation: reservation
        """

    @abstractmethod
    def remove(self, *, reservation: IBrokerReservation):
        """
        Remove a reservation
        @param reservation: reservation
        """

    @abstractmethod
    def size(self) -> int:
        """
        Return the size of queue
        @return size of queue
        """

    @abstractmethod
    def values(self) -> List[IBrokerReservation]:
        """
        Return values
        @return values
        """

==> fabric-cf-1.4.0b1.tar.gz: fabric-cf-1.4.0b1/fabric_cf/actor/core/policy/queue_wrapper.py <==
#!/usr/bin/env python3
# MIT License
#
# Copyright (c) 2020 FABRIC Testbed
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in all
# copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
#
#
# Author: Komal Thareja (kthare10@renci.org)
from __future__ import annotations

from abc import abstractmethod
from typing import TYPE_CHECKING, List

if TYPE_CHECKING:
    from fabric_cf.actor.core.apis.abc_broker_reservation import ABCBrokerReservation


class QueueWrapper:
    @abstractmethod
    def add(self, *, reservation: ABCBrokerReservation):
        """
        Add a reservation
        @param reservation: reservation
        """

    @abstractmethod
    def remove(self, *, reservation: ABCBrokerReservation):
        """
        Remove a reservation
        @param reservation: reservation
        """

    @abstractmethod
    def size(self) -> int:
        """
        Return the size of queue
        @return size of queue
        """

    @abstractmethod
    def values(self) -> List[ABCBrokerReservation]:
        """
        Return values
        @return values
        """
